netapp_ontap.models.log_retention API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.log_retention`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LogRetentionSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LogRetention object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `count GET POST PATCH`

    Determines how many audit log files to retain before rotating the oldest log file out. This is mutually exclusive with duration.

  `duration GET POST PATCH`

    Specifies an ISO-8601 format date and time to retain the audit log file. The audit log files are deleted once they reach the specified date/time. This is mutually exclusive with count.

    Example: P4DT12H30M5S